@@ -1,3 +1,21 @@
+/* Tower Toppler - Nebulus
+ * Copyright (C) 2000-2003  Andreas Rver
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ */
+
 #include "elevators.h"
 
 #include "level.h"
@@ -6,11 +24,11 @@
 
 #include <stdlib.h>
 
-#define MAX_ELE 4
+#define MAX_ELE 10
 
-/* elevators are handled in a quite complicated manner: while
+/* elevators are handled in a quite complicated way: while
  the toppler is moving on the elevator the platform is invisible
- and frawn together with the toppler. The stick below the elevator
+ and drawn together with the toppler. The stick below the elevator
  is always drawn in such a way that the last one will appear or disappear
  below the platform under the toppler */
 
@@ -22,7 +40,7 @@ static struct {
   /* time until the elevator falls down */
   Sint8 time;
 
-  /* backgound value necesary because in between the stations it
+  /* background value necessary because in between the stations it
    is impossible to show a platform so we save the actual value
    there and force a station at the position, when the elevator moves
    further down we restore the value there */
@@ -38,12 +56,11 @@ void ele_init(void) {
     elevators[t].time = -1;
 
   active_ele = -1;
-
 }
 
 void ele_select(Uint16 row, Uint8 col) {
 
-  assert(active_ele == -1, "select more than one elevator\n");
+  assert(active_ele == -1, "Select more than one elevator.");
 
   Uint8 what = 0;
 
@@ -70,7 +87,7 @@ void ele_select(Uint16 row, Uint8 col) {
 
 void ele_activate(Sint8 dir) {
 
-  assert(active_ele != -1, "work with unselected elevator, activate\n");
+  assert(active_ele != -1, "Work with unselected elevator, activate.");
 
   lev_platform2stick(elevators[active_ele].vertical, elevators[active_ele].angle);
   ele_dir = dir;
@@ -79,7 +96,7 @@ void ele_activate(Sint8 dir) {
 
 void ele_move(void) {
 
-  assert(active_ele != -1, "work with unselected elevator, move\n");
+  assert(active_ele != -1, "Work with unselected elevator, move.");
 
   if (ele_dir == 1) {
     elevators[active_ele].vertical++;
@@ -94,7 +111,7 @@ void ele_move(void) {
 
 bool ele_is_atstop(void) {
 
-  assert(active_ele != -1, "work with unselected elevator, is_at_stop\n");
+  assert(active_ele != -1, "Work with unselected elevator, is_atstop.");
 
   if (ele_dir == 1)
     return lev_is_station(elevators[active_ele].vertical + 1, elevators[active_ele].angle);
@@ -104,7 +121,7 @@ bool ele_is_atstop(void) {
 
 void ele_deactivate(void) {
 
-  assert(active_ele != -1, "deselected an inactive elevator\n");
+  assert(active_ele != -1, "Deselected an inactive elevator.");
 
   if (ele_dir == 1) ele_move();
 
